@@ -12,7 +12,6 @@ from enaml.widgets.image_view import ProxyImageView
 from .QtGui import QFrame, QPainter, QPixmap
 
 from .q_resource_helpers import get_cached_qimage
-from .qt_constraints_widget import size_hint_guard
 from .qt_control import QtControl
 
 
@@ -224,7 +223,7 @@ class QtImageView(QtControl, ProxyImageView):
         """
         super(QtImageView, self).init_widget()
         d = self.declaration
-        self.set_image(d.image)
+        self.set_image(d.image, guard=False)
         self.set_scale_to_fit(d.scale_to_fit)
         self.set_allow_upscaling(d.allow_upscaling)
         self.set_preserve_aspect_ratio(d.preserve_aspect_ratio)
@@ -232,7 +231,7 @@ class QtImageView(QtControl, ProxyImageView):
     #--------------------------------------------------------------------------
     # Widget Update Methods
     #--------------------------------------------------------------------------
-    def set_image(self, image, sh_guard=True):
+    def set_image(self, image, guard=True):
         """ Set the image on the underlying widget.
 
         """
@@ -240,8 +239,8 @@ class QtImageView(QtControl, ProxyImageView):
         if image:
             qimage = get_cached_qimage(image)
             qpixmap = QPixmap.fromImage(qimage)
-        if sh_guard:
-            with size_hint_guard(self):
+        if guard:
+            with self.geometry_guard():
                 self.widget.setPixmap(qpixmap)
         else:
             self.widget.setPixmap(qpixmap)
