@@ -1,28 +1,30 @@
 #------------------------------------------------------------------------------
-#  Copyright (c) 2011, Enthought, Inc.
-#  All rights reserved.
+# Copyright (c) 2013, Nucleic Development Team.
+#
+# Distributed under the terms of the Modified BSD License.
+#
+# The full license is in the file COPYING.txt, distributed with this software.
 #------------------------------------------------------------------------------
-from traits.api import HasTraits, Str, Range, Bool, on_trait_change
+from atom.api import Atom, Unicode, Range, Bool, observe
 
 import enaml
-from enaml.stdlib.sessions import simple_session
 from enaml.qt.qt_application import QtApplication
 
 
-class Person(HasTraits):
+class Person(Atom):
     """ A simple class representing a person object.
 
     """
-    last_name = Str
+    last_name = Unicode()
 
-    first_name = Str
+    first_name = Unicode()
 
     age = Range(low=0)
 
     debug = Bool(False)
 
-    @on_trait_change('age')
-    def debug_print(self):
+    @observe('age')
+    def debug_print(self, change):
         """ Prints out a debug message whenever the person's age changes.
 
         """
@@ -41,11 +43,8 @@ if __name__ == '__main__':
     john = Person(first_name='John', last_name='Doe', age=42)
     john.debug = True
 
-    session = simple_session(
-        'john', 'A view of the Person john', PersonView, person=john
-    )
+    app = QtApplication()
+    view = PersonView(person=john)
+    view.show()
 
-    app = QtApplication([session])
-    app.start_session('john')
     app.start()
-
